package com.xinelu.manage.mapper.patienttaskpushrecord;

import com.xinelu.manage.domain.patienttaskpushrecord.PatientTaskPushRecord;

import java.util.List;


/**
 * 患者管理任务推送方式记录Mapper接口
 *
 * @author xinelu
 * @date 2024-03-21
 */
public interface PatientTaskPushRecordMapper {
    /**
     * 查询患者管理任务推送方式记录
     *
     * @param id 患者管理任务推送方式记录主键
     * @return 患者管理任务推送方式记录
     */
    public PatientTaskPushRecord selectPatientTaskPushRecordById(Long id);

    /**
     * 查询患者管理任务推送方式记录列表
     *
     * @param patientTaskPushRecord 患者管理任务推送方式记录
     * @return 患者管理任务推送方式记录集合
     */
    List<PatientTaskPushRecord> selectPatientTaskPushRecordList(PatientTaskPushRecord patientTaskPushRecord);

    /**
     * 新增患者管理任务推送方式记录
     *
     * @param patientTaskPushRecord 患者管理任务推送方式记录
     * @return 结果
     */
    int insertPatientTaskPushRecord(PatientTaskPushRecord patientTaskPushRecord);

    /**
     * 修改患者管理任务推送方式记录
     *
     * @param patientTaskPushRecord 患者管理任务推送方式记录
     * @return 结果
     */
    int updatePatientTaskPushRecord(PatientTaskPushRecord patientTaskPushRecord);

    /**
     * 删除患者管理任务推送方式记录
     *
     * @param id 患者管理任务推送方式记录主键
     * @return 结果
     */
    int deletePatientTaskPushRecordById(Long id);

    /**
     * 批量删除患者管理任务推送方式记录
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deletePatientTaskPushRecordByIds(Long[] ids);
}
